dnl @synopsis PFK_HAVE_QT4 [--with-qt4-dir=DIR]
dnl
dnl Search for qt4 libraries
dnl
dnl The following shell variable is set to either "yes" or "no":
dnl
dnl   have_qt4
dnl
dnl Additionally, the following variables are exported:
dnl
dnl   QT)DIR
dnl   QT_CXXFLAGS
dnl   QT_LIBS
dnl   QT_UIC
dnl   QT_MOC
dnl
dnl which contain the flags pointing to the Qt 4 directories,
dnl
dnl No common variables such as $LIBS or $CFLAGS are polluted.
dnl 
dnl 
dnl Options:
dnl
dnl --with-qt4sys=DIR: DIR should point to where the qt4
dnl include and lib directories are found
dnl
dnl If the options "=no" or, equivalently,
dnl --without-qt4sys
dnl "have_qt4" is set to "no" and the other variables are unchanged.
dnl
dnl @version $Id: pfk_have_qt4.m4,v 1.8 2008/05/11 17:07:38 pfkeb Exp $
dnl @author <Paul_Kunz@slac.stanford.edu> base on bnv_have_qt.mr by
dnl
AC_DEFUN([PFK_HAVE_QT4],
[
  AC_REQUIRE([AC_PROG_CXX])

  AC_ARG_WITH([qt4-dir],
   [  --with-qt4-dir=DIR        Qt 4 dir is DIR
                                (default:none)],
   [pfk_qt4_dir=$with_qt4_dir],
   [pfk_qt4_dir="/usr/local/Trolltech/Qt-4.4.0"])

  AC_ARG_WITH([qt4-include],
    [  --with-qt4-include=DIR    include path is DIR 
                                  (default:/usr/local/Trolltech/Qt-4.4.0/include)],
    [pfk_qt4_include=$with_qt4_include],
    [pfk_qt4_include="$pfk_qt4_dir/include"])

  AC_ARG_WITH([qt4-lib],
    [  --with-qt4-lib=DIR        library path  is DIR 
                                  (default:/usr/local/Trolltech/Qt-4.4.0/lib)],
    [pfk_qt4_lib=$with_qt4_lib],
    [pfk_qt4_lib="$pfk_qt4_dir/lib"])

  AC_MSG_NOTICE([checking QT4 install] )

  PFK_SHARED_SUFFIX
  qt4_good=no
  AC_CHECK_FILE($pfk_qt4_include/QtGui/QAbstractButton,, qt4_good=yes )
  AC_CHECK_FILE($pfk_qt4_lib/libQtCore.$pfk_so,, qt4_good=yes )

  if test x$qt4_good = xyes; then
    have_qt4=no
  else
    have_qt4=yes
  fi

  if test x"$have_qt4" = xyes; then
    AC_DEFINE(HAVE_QT4, 1,
      Define to 1 if QT4 is available )
    QT_CXXFLAGS="-I$pfk_qt4_include -I$pfk_qt4_include/Qt -DQT_COMPAT -DQT3_SUPPORT"
    pfk_libs="-lQtGui -lQtCore -lQt3Support"
    if test x$enable_rpath = xno; then
      QT_LIBS="-L$pfk_qt4_lib $pfk_libs"
    else
      QT_LIBS="-L$pfk_qt4_lib $pfk_libs -R $pfk_qt4_lib"
    fi
    QT_DIR="$pfk_qt4_dir"
    QT_UIC="$pfk_qt4_dir/bin/uic3"
    QT_MOC="$pfk_qt4_dir/bin/moc"
  else
    AC_MSG_WARN(Qt4 not found)
  fi

  AC_SUBST(QT_DIR)
  AC_SUBST(QT_CXXFLAGS)
  AC_SUBST(QT_LIBS)
  AC_SUBST(QT_UIC)
  AC_SUBST(QT_MOC)
])
