dnl @synopsis PFK_HAVE_BOOST [--with-boost-include=DIR] [--with-boost-lib=DIR]
dnl
dnl Sets the paths and library name for boost.python.
dnl
dnl Sets the paths for include and libraries, and boost.python
dnl library name. If the user doesn't supply input then sets the defaults.
dnl
dnl Tthe following variables are exported:
dnl
dnl   BOOST_CXXFLAGS
dnl   BOOST_LDFLAGS
dnl
dnl Example lines for Makefile.in:
dnl
dnl   INCLUDES = @BOOST_CXXFLAGS@
dnl
dnl @version $Id: pfkeb_have_boost.m4,v 1.29 2007/06/29 18:29:59 pfkeb Exp $
dnl @author <Paul_Kunz@slac.stanford.edu> based on bnv_have_qt.mr by
dnl

AC_DEFUN([PFK_HAVE_BOOST],
[
  AC_ARG_WITH([boost-version],
    [  --with-boost-version=VER     boost version (default: 1_33_1)],
    [pfk_boost_version=$with_boost_version],
    [pfk_boost_version=1_33_1])

  AC_ARG_WITH([boost-root],
    [  --with-boost-root=DIR        root of boost install
                                    (default: /usr/local)],
    [pfk_boost_root=$with_boost_root],
    [pfk_boost_root="/usr/local"])

  AC_ARG_WITH([boost-include],
    [  --with-boost-include=DIR     boost include files are in DIR/boost
                                    (default: /usr/local/include/boost-1_33_1)],
	[pfk_boost_include=$with_boost_include],
        [pfk_boost_include="$pfk_boost_root/include/boost-$pfk_boost_version"])

  AC_ARG_WITH([boost-lib],
    [  --with-boost-lib=LIB         boost library files is in LIB
                                    (default: /usr/local/lib)],
	[pfk_boost_lib=$with_boost_lib],
        [pfk_boost_lib="$pfk_boost_root/lib"])

  AC_ARG_WITH([boost-libname],
    [  --with-boost-libname=LIBNAME boost library file is LIBNAME
                                    (default: boost_python-gcc-1_33_1)],
       [pfk_boost_libname=$with_boost_libname],
       [pfk_boost_libname="boost_python-gcc-$pfk_boost_version"] )

  BOOST_CXXFLAGS="-I$pfk_boost_include"
  if test x$enable_rpath = xno; then
    BOOST_LDFLAGS="-L$pfk_boost_lib -l$pfk_boost_libname"
  else
    BOOST_LDFLAGS="-L$pfk_boost_lib -l$pfk_boost_libname -R$pfk_boost_lib"
  fi
  BOOST_LIBNAME="$pfk_boost_libname"

  AC_MSG_NOTICE([checking boost installation with
    BOOST_CXXFLAGS=$BOOST_CXXFLAGS ])

  AC_LANG_SAVE
  AC_LANG_CPLUSPLUS
  ac_save_CPPFLAGS="$CPPFLAGS"
  CPPFLAGS="$BOOST_CXXFLAGS -I$PY_INCLUDE"

  pfk_have_boost=yes
  AC_CHECK_FILE([$pfk_boost_include/boost/python.hpp], good=yes, good=no )

  if ! test x"$good" = xyes; then
     CPPFLAGS="-I/usr/include -I$PY_INCLUDE"
     AC_MSG_NOTICE([checking boost installation with
    BOOST_CXXFLAGS=])

     AC_CHECK_FILE([/usr/include/boost/python.hpp], good=yes, good=no )
     if ! test x"$good" = xyes; then
       pfk_have_boost=no
       AC_MSG_WARN([
          Build will fail to build Python module, the last step])
     else
       BOOST_CXXFLAGS=""
     fi
  fi 

  CPPFLAGS="$ac_save_CPPFLAGS"
  AC_LANG_RESTORE

  if ! (test x"$pfk_boost_version" = x1_32 || \
          test x"$pfk_boost_version" = x1_33 || \
          test x"$pfk_boost_version" = x1_33_1 || \
          test x"$pfk_boost_version" = x1_34 ); then
      AC_DEFINE(BOOST_DEFECT,1,[define if older version of Boost])
  fi

  AC_MSG_NOTICE([checking boost installation with
    BOOST_LDFLAGS=$BOOST_LDFLAGS] )
  PFK_SHARED_SUFFIX
  pfk_boost_library="$pfk_boost_lib/lib$pfk_boost_libname."$pfk_so
  AC_CHECK_FILE([$pfk_boost_library], good=yes, good=no )

  pfk_save_CXXFLAGS=$CXXFLAGS
  if ! test x"$good" = xyes; then
  BOOST_LDFLAGS="-lboost_python"
  AC_MSG_NOTICE([checking boost installation with
    BOOST_LDFLAGS=$BOOST_LDFLAGS])
  CXXFLAGS="$CXXFLAGS -I /usr/include/python$PYTHON_VERSION"
  AC_CHECK_LIB(boost_python, main, good=yes, good=no, -lpython$PYTHON_VERSION)
    if ! test x"$good" = xyes; then
      pfk_have_boost=no
      AC_MSG_WARN([
      Build will fail to build Python module, the last step])
	BOOST_LDFLAGS=
    fi
  fi
  CXXFLAGS=$pfk_save_CXXFLAGS
  AC_SUBST(BOOST_CXXFLAGS) AC_SUBST(BOOST_LDFLAGS)
])
