 dnl @synopsis PFK_HAVE_CFITSIO [--with-cfitsio-include=DIR] [--with-cfitsio-lib=DIR]
dnl
dnl Search for Cfitsio libraries
dnl
dnl The following shell variable is set to either "yes" or "no":
dnl
dnl   have_cfitsio
dnl
dnl Additionally, the following variables are exported:
dnl
dnl   CFITSIO_CXXFLAGS
dnl   CFITSIO_LDFLAGS 
dnl
dnl Example lines for Makefile.in:
dnl
dnl   INCLUDES = @CFITSIO_CXXFLAGS@
dnl
dnl Options:
dnl
dnl --with-cfitsio-include=DIR: DIR should point to where the minuit
dnl include directory can be found, as in -IDIR.  If not given, first looks in 
dnl /usr/local/include, then /usr/include/cfitsio (as done with Fedora Core
dnl rpm.
dnl
dnl --with-cfitsio-lib=DIR: DIR should point to the where the libraries 
dnl can be found as in -LDIR  If not given, first looks in usr/local/lib
dnl then in usr/lib
dnl
dnl If at least one of the options "=no" or, equivalently,
dnl --without-cfitsio-include and/or --without-cfitsio-lib is given, 
dnl "have_cfitsio" is set to "no" and the other variables are set to the 
dnl empty string.
dnl
dnl @version $Id: pfkeb_have_cfitsio.m4,v 1.12 2007/04/02 17:22:42 pfkeb Exp $
dnl @author <Paul_Kunz@slac.stanford.edu> base on bnv_have_qt.mr by
dnl
AC_DEFUN([PFK_HAVE_CFITSIO],
[
  AC_REQUIRE([AC_PROG_CXX])

  AC_ARG_WITH([cfitsio-include],
    [  --with-cfitsio-include=DIR cfitsio include directory is in DIR 
                                  (default:/usr/local/include:/usr/include)],
    [pfk_cfitsio_include=$with_cfitsio_include],
    [pfk_cfitsio_include="/usr/local/include"])

  AC_ARG_WITH([cfitsio-lib],
    [  --with-cfitsio-lib=DIR     cfitsio libfitsio.so file is in DIR 
                                  (default:/usr/local/lib:/usr/lib)],
    [pfk_cfitsio_lib=$with_cfitsio_lib],
    [pfk_cfitsio_lib="/usr/local/lib"])

  CFITSIO_CXXFLAGS="-I$pfk_cfitsio_include"
  if test x$pfk_cfitsio_include != xno && test x$pfk_cfitsio_lib != xno; then
    if test x$enable_rpath = xno; then
      CFITSIO_LDFLAGS="-L$pfk_cfitsio_lib -lcfitsio"
    else
      CFITSIO_LDFLAGS="-L$pfk_cfitsio_lib -lcfitsio -R $pfk_cfitsio_lib"
    fi

    AC_MSG_NOTICE([checking cfitsio install with
      CFITSIO_CXXFLAGS=$CFITSIO_CXXFLAGS
      CFITSIO_LDFLAGS=$CFITSIO_LDFLAGS])

    PFK_SHARED_SUFFIX
    no_good=no
    AC_CHECK_FILE($pfk_cfitsio_include/fitsio.h,, no_good=yes )
    AC_CHECK_FILE($pfk_cfitsio_lib/libcfitsio.$pfk_so,, no_good=yes )

    if test x$no_good = xyes; then
      CFITSIO_CXXFLAGS="-I/usr/include/cfitsio"
      CFITSIO_LDFLAGS="-lcfitsio"
      AC_MSG_NOTICE([checking cfitsio install with
      CFITSIO_CXXFLAGS=$CFITSIO_CXXFLAGS
      CFITSIO_LDFLAGS=$CFITSIO_LDFLAGS])

      no_good=no
dnl check standard system places use FITS short names for link test
      AC_CHECK_FILE(/usr/include/cfitsio/fitsio.h,, no_good=yes )
      AC_CHECK_LIB(cfitsio, ffcmsg,,no_good=yes )
      if test x$no_good = xyes; then
        have_cfitsio=no
      else
       have_cfitsio=yes
      fi
    else
      have_cfitsio=yes
    fi
  else
    have_cfitsio=no
  fi
  if test x$have_cfitsio = xyes; then
    AC_DEFINE(HAVE_CFITSIO, 1,Define to 1 if cfitsio is available)
  else
    CFITSIO_CXXFLAGS=
    CFITSIO_LDFLAGS=
    AC_MSG_WARN(cfitsio not found)
  fi
  AC_SUBST(CFITSIO_CXXFLAGS) 
  AC_SUBST(CFITSIO_LDFLAGS) 
])
