dnl @synopsis PFK_HAVE_MINUIT [--with-minuit-include=DIR] [--with-minuit-lib=DIR]
dnl
dnl Search for minuit libraries
dnl
dnl The following shell variable is set to either "yes" or "no":
dnl
dnl   have_minuit
dnl
dnl Additionally, the following variables are exported:
dnl
dnl   MINUIT_CXXFLAGS
dnl   MINUIT_LDFLAGS
dnl
dnl Example lines for Makefile.in:
dnl
dnl   INCLUDES = @MINUIT_CXXFLAGS@
dnl
dnl Options:
dnl
dnl --with-minuit-include=DIR: DIR should point to where the minuit
dnl include directory can be found, as in -IDIR.
dnl
dnl --with-minuit-lib=DIR: DIR should point to the where the libraries 
dnl can be found as in -LDIR
dnl
dnl --with-minuit-libname=NAME NAME should be name
dnl
dnl If at least one of the options "=no" or, equivalently,
dnl --without-minuit-include and/or --without-minuit-lib is given, 
dnl "have_minuit" is set to "no" and the other variables are set to the 
dnl empty string.
dnl
dnl @version $Id: pfkeb_have_minuit.m4,v 1.20 2006/09/21 22:55:28 pfkeb Exp $
dnl @author <Paul_Kunz@slac.stanford.edu> base on bnv_have_qt.mr by
dnl
AC_DEFUN([PFK_HAVE_MINUIT],
[
  AC_REQUIRE([AC_PROG_CXX])

  AC_ARG_WITH([minuit-include],
    [  --with-minuit-include=DIR  Minuit include directory is in DIR 
                                  (default:/usr/local/include)],
    [pfk_minuit_include=$with_minuit_include],
    [pfk_minuit_include="/usr/local/include"])

  AC_ARG_WITH([minuit-lib],
    [  --with-minuit-lib=DIR      Minuit libMinuit.so file is in DIR 
                                  (default:/usr/local/lib)],
    [pfk_minuit_lib=$with_minuit_lib],
    [pfk_minuit_lib="/usr/local/lib"])

  AC_ARG_WITH([minuit-libname],
    [  --with-minuit-libname=NAME Minuit library name is NAME
                                  (default: lcg_Minuit)],
    [pfk_minuit_libname=$with_minuit_libname],
    [pfk_minuit_libname="lcg_Minuit"] )

  MINUIT_CXXFLAGS="-I$pfk_minuit_include"
  if test x$enable_rpath = xno; then
    MINUIT_LDFLAGS="-L$pfk_minuit_lib -l$pfk_minuit_libname"
  else
    MINUIT_LDFLAGS="-L$pfk_minuit_lib -l$pfk_minuit_libname -R$pfk_minuit_lib"
  fi

  AC_MSG_NOTICE([checking Minuit install with
    MINUIT_CXXFLAGS=$MINUIT_CXXFLAGS
    MINUIT_LDFLAGS=$MINUIT_LDFLAGS ] )

  PFK_SHARED_SUFFIX
  no_good=no
  AC_CHECK_FILE($pfk_minuit_include/Minuit/FCNBase.h,, no_good=yes )
  AC_CHECK_FILE($pfk_minuit_lib/lib$pfk_minuit_libname.$pfk_so,, no_good=yes )

  if test x$no_good = xyes; then
    have_minuit=no
  else
    have_minuit=yes
  fi
  if test x"$have_minuit2" = xyes; then
    have_minuit=no
  fi
  if test x"$have_minuit" = xyes; then
    AC_DEFINE(HAVE_MINUIT, 1,
      Define to 1 if C++ version of Minuit is available )
  else
    MINUIT_CXXFLAGS=
    MINUIT_LDFLAGS=
    AC_MSG_WARN(Minuit not found)
  fi
  AC_SUBST(MINUIT_CXXFLAGS) 
  AC_SUBST(MINUIT_LDFLAGS)
])
