dnl @synopsis PFK_HAVE_MINUIT2 [--with-minuit2-include=DIR] [--with-minuit2-lib=DIR]
dnl
dnl Search for Minuit2 libraries
dnl
dnl The following shell variable is set to either "yes" or "no":
dnl
dnl   have_minuit2
dnl
dnl Additionally, the following variables are exported:
dnl
dnl   MINUIT2_CXXFLAGS
dnl   MINUIT2_LDFLAGS 
dnl
dnl Example lines for Makefile.in:
dnl
dnl   INCLUDES = @MINUIT2_CXXFLAGS@
dnl
dnl Options:
dnl
dnl --with-minuit2-include=DIR: DIR should point to where the minuit
dnl include directory can be found, as in -IDIR.  If not given, first looks in 
dnl /usr/local/include, then /usr/include
dnl
dnl --with-minuit2-lib=DIR: DIR should point to the where the libraries 
dnl can be found as in -LDIR  If not given, first looks in usr/local/lib
dnl then in usr/lib
dnl
dnl If at least one of the options "=no" or, equivalently,
dnl --without-minuit2-include and/or --without-minuit2-lib is given, 
dnl "have_minuit2" is set to "no" and the other variables are set to the 
dnl empty string.
dnl
dnl @version $Id: pfkeb_have_minuit2.m4,v 1.9 2009/10/02 22:34:14 pfkeb Exp $
dnl @author <Paul_Kunz@slac.stanford.edu> base on bnv_have_qt.mr by
dnl
AC_DEFUN([PFK_HAVE_MINUIT2],
[
  AC_REQUIRE([AC_PROG_CXX])

  AC_ARG_WITH([minuit2-include],
    [  --with-minuit2-include=DIR Minuit2 include directory is in DIR 
                                  (default:/usr/local/include:/usr/include)],
    [pfk_minuit2_include=$with_minuit2_include],
    [pfk_minuit2_include="/usr/local/include"])

  AC_ARG_WITH([minuit2-lib],
    [  --with-minuit2-lib=DIR     Minuit2 libMinuit2.so file is in DIR 
                                  (default:/usr/local/lib:/usr/lib)],
    [pfk_minuit2_lib=$with_minuit2_lib],
    [pfk_minuit2_lib="/usr/local/lib"])

  if test $pfk_minuit2_include == no -o $pfk_minuit2_lib == no; then
    AC_MSG_NOTICE([Minuit2 disabled])
  else
    MINUIT2_CXXFLAGS="-I$pfk_minuit2_include -fopenmp"
    if test x$enable_rpath = xno; then
      MINUIT2_LDFLAGS="-L$pfk_minuit2_lib -lMinuit2"
    else
      MINUIT2_LDFLAGS="-Wl,-fopenmp -Wl,-shared -L$pfk_minuit2_lib -lMinuit2 -R$pfk_minuit2_lib"
    fi
    AC_MSG_NOTICE([checking Minuit2 install with
      MINUIT2_CXXFLAGS=$MINUIT2_CXXFLAGS
      MINUIT2_LDFLAGS=$MINUIT2_LDFLAGS])

    PFK_SHARED_SUFFIX
    no_good=no
    AC_CHECK_FILE($pfk_minuit2_include/Minuit2/FCNBase.h,, no_good=yes )
    AC_CHECK_FILE($pfk_minuit2_lib/libMinuit2.$pfk_so,, no_good=yes )

    if test x$no_good = xyes; then
    MINUIT2_CXXFLAGS="-I/usr/include"
    MINUIT2_LDFLAGS="-L/usr/lib -lMinuit2"
      AC_MSG_NOTICE([checking Minuit2 install with
        MINUIT2_CXXFLAGS=$MINUIT2_CXXFLAGS
        MINUIT2_LDFLAGS=$MINUIT2_LDFLAGS])

      no_good=no
      AC_CHECK_FILE(/usr/include/Minuit2/FCNBase.h,, no_good=yes )
      AC_CHECK_FILE(/usr/lib/libMinuit2.$pfk_so,, no_good=yes )
      if test x$no_good = xyes; then
        have_minuit2=no
      else
        have_minuit2=yes
        have_minuit=no
      fi
    else
      have_minuit2=yes
      have_minuit=no
    fi
  fi

  if test x$have_minuit2 = xyes; then
    AC_DEFINE(HAVE_MINUIT2, 1,Define to 1 if Minuit2 is available)
  else
    MINUIT2_CXXFLAGS=
    MINUIT2_LDFLAGS=
    AC_MSG_WARN(Minuit2 not found)
  fi
  AC_SUBST(MINUIT2_CXXFLAGS) 
  AC_SUBST(MINUIT2_LDFLAGS) 
])
