dnl @synopsis PFK_HAVE_ROOT [--with-rootsys=DIR]
dnl
dnl Search for root libraries
dnl
dnl The following shell variable is set to either "yes" or "no":
dnl
dnl   have_root
dnl
dnl Additionally, the following variables are exported:
dnl
dnl   ROOT_CXXFLAGS
dnl   ROOT_LDFLAGS
dnl
dnl which contain an "-I" flag pointing to the Qt include directory, link flags
dnl necessary to link with root.
dnl
dnl Example lines for Makefile.in:
dnl
dnl   INCLUDES = @ROOT_CXXFLAGS@
dnl
dnl No common variables such as $LIBS or $CFLAGS are polluted.
dnl
dnl Options:
dnl
dnl --with-rootsys=DIR: DIR should point to where the root
dnl include and lib directories are found
dnl
dnl If the options "=no" or, equivalently,
dnl --without-rootsys
dnl "have_root" is set to "no" and the other variables are set to the 
dnl empty string.
dnl
dnl @version $Id: pfkeb_have_root.m4,v 1.13 2007/11/29 22:57:48 pfkeb Exp $
dnl @author <Paul_Kunz@slac.stanford.edu> base on bnv_have_qt.mr by
dnl
AC_DEFUN([PFK_HAVE_ROOT],
[
  AC_REQUIRE([AC_PROG_CXX])
#   have_root="yes"

  # set defaults
#   pfk_root_include="/usr/local/include/root"
#   pfk_root_lib="/usr/local/lib/root"

  AC_ARG_WITH([root-include],
    [  --with-root-include=DIR    include path is DIR 
                                  (default:/usr/local/include/root)],
    [pfk_root_include=$with_root_include],
    [pfk_root_include="/usr/local/include/root"])

  AC_ARG_WITH([root-lib],
    [  --with-root-lib=DIR        library path  is DIR 
                                  (default:/usr/local/lib/root)],
    [pfk_root_lib=$with_root_lib],
    [pfk_root_lib="/usr/local/lib/root"])

  ROOT_CXXFLAGS="-I$pfk_root_include"
  AC_CHECK_FILE($pfk_root_lib/libRIO.so, R16LIB="-lRIO -lNet", R16LIB="" )
  pfk_libs="-lCore -lCint -lTree $R16LIB -lMatrix -lHist"

  if test x$enable_rpath = xno; then
    ROOT_LDFLAGS="-L$pfk_root_lib $pfk_libs"
  else
    ROOT_LDFLAGS="-L$pfk_root_lib $pfk_libs -R $pfk_root_lib"
  fi

  AC_MSG_NOTICE([checking ROOT install with
    ROOT_CXXFLAGS=$ROOT_CXXFLAGS
    ROOT_LDFLAGS=$ROOT_LDFLAGS ] )

  root_good=no
  AC_CHECK_FILE($pfk_root_include/TTree.h,, root_good=yes )
  AC_CHECK_FILE($pfk_root_lib/libCore.so,, root_good=yes )

  if test x$root_good = xyes; then
    have_root=no
  else
    have_root=yes
  fi

dnl If ROOT is available and Minuit not available, then try to find
dnl Minuit2 in the ROOT installation.

  if test x$have_root = xyes; then
    if ! test x$have_minuit = xyes; then
       if ! test x$have_minuit2 = xyes; then
	 not_good=no
         AC_CHECK_FILE($pfk_root_include/Minuit2/FCNBase.h,,not_good=yes)
         AC_CHECK_FILE($pfk_root_lib/libMinuit2.so,,not_good=yes)
	if test x$not_good = yes; then
	   AC_MSG_WARN(Minuit2 not found in ROOT installation)
        else
	   AC_DEFINE(HAVE_MINUIT2, 1, Define to 1 if Minuit2 is available)
           MINUIT2_CXXFLAGS="-I$pfk_root_include"
           MINUIT2_LDFLAGS="-L$pfk_root_lib -lMinuit2 -lGraf -R$pfk_root_lib"
           AC_SUBST(MINUIT2_CXXFLAGS)
           AC_SUBST(MINUIT2_LDFLAGS)
           have_minuit2=yes
        fi
       fi
    fi
  fi

  if test x"$have_root" = xyes; then
    AC_DEFINE(HAVE_ROOT, 1,
      Define to 1 if ROOT is available )
  else
    ROOT_CXXFLAGS=
    ROOT_LDFLAGS=
    AC_MSG_WARN(Root not found)
  fi

  AC_SUBST(ROOT_CXXFLAGS)
  AC_SUBST(ROOT_LDFLAGS)
])
