dnl @synopsis PFK_HAVE_WCSLIB [--with-wcslib-include=DIR] [--with-wcslib-lib=DIR]
dnl
dnl Search for wcslib libraries
dnl
dnl The following shell variable is set to either "yes" or "no":
dnl
dnl   have_wcslib
dnl
dnl Additionally, the following variables are exported:
dnl
dnl   WCSLIB_CXXFLAGS
dnl   WCSLIB_LIB
dnl
dnl Example lines for Makefile.in:
dnl
dnl   INCLUDES = @WCSLIB_CXXFLAGS@
dnl
dnl Options:
dnl
dnl --with-wcslib-include=DIR: DIR should point to where the wcslib
dnl include directory can be found, as in -IDIR.
dnl
dnl --with-wcslib-lib=DIR: DIR should point to the where the libraries 
dnl can be found as in -LDIR
dnl
dnl If at least one of the options "=no" or, equivalently,
dnl --without-wcslib-include and/or --without-wcslib-lib is given, 
dnl "have_wcslib" is set to "no" and the other variables are set to the 
dnl empty string.
dnl
dnl @version $Id: pfkeb_have_wcslib.m4,v 1.10 2007/07/27 17:43:19 pfkeb Exp $
dnl @author <Paul_Kunz@slac.stanford.edu> base on bnv_have_qt.mr by
dnl
AC_DEFUN([PFK_HAVE_WCSLIB],
[
  AC_ARG_WITH([wcslib-include],
    [  --with-wcslib-include=DIR  wcslib include directory is in DIR 
                                  (default:/usr/local/include)],
    [pfk_wcslib_include=$with_wcslib_include],
    [pfk_wcslib_include="/usr/local/include"])

  AC_ARG_WITH([wcslib-lib],
    [  --with-wcslib-lib=DIR      wcslib libwcs.a file is in DIR 
                                  (default:/usr/local/lib)],
    [pfk_wcslib_lib=$with_wcslib_lib],
    [pfk_wcslib_lib="/usr/local/lib"])

  WCSLIB_CXXFLAGS="-I$pfk_wcslib_include"
  if test x$pfk_wcslib_include != xno && test x$pfk_wcslib_lib != xno; then
    WCSLIB_LDFLAGS="-L$pfk_wcslib_lib -lwcs"
  fi
  AC_MSG_NOTICE([checking WCSLIB install with
    WCSLIB_CXXFLAGS=$WCSLIB_CXXFLAGS
    WCSLIB_LDFLAGS=$WCSLIB_LDFLAGS])

  if test x$enable_rpath = xyes; then
     WCSLIB_LDFLAGS="$WCSLIB_LDFLAGS -R $pfk_wcslib_lib"
  fi
  no_good=no
  pfk_save_ldflags=$LDFLAGS
  pfk_save_libs=$LIBS
  LDFLAGS=$WCSLIB_LDFLAGS
  AC_CHECK_FILE($pfk_wcslib_include/wcslib/wcs.h,, no_good=yes )
  AC_CHECK_LIB(wcs, wcsset, no_good=no, no_good=yes )
  LDFLAGS=$pfk_save_ldflags
# do not want -lwcs in LIBS
  LIBS=$pfk_save_libs
  if test x$no_good = xyes; then
    have_wcslib=no
  else
    have_wcslib=yes
  fi

  if test x"$have_wcslib" = xyes; then
    AC_DEFINE(HAVE_WCSLIB, 1,
      Define to 1 if WCSLIB is available )
  else
    WCSLIB_CXXFLAGS=
    WCSLIB_LDFLAGS=
    AC_MSG_WARN(WCSLIB not found)
  fi
  AC_SUBST(WCSLIB_CXXFLAGS) 
  AC_SUBST(WCSLIB_LDFLAGS) 
])
