/** @file 

Part of Python extension module for hippodraw::PyNTuple class.

Copyright (C) 2000-2004, 2006, 2009 The Board of Trustees of The
Leland Stanford Junior University.  All Rights Reserved.

$Id: export_PyNTuple.cxx,v 1.1 2009/08/09 21:19:26 pfkeb Exp $

*/

#ifdef _MSC_VER
// nonstandard extension used 'extern' before...
# pragma warning(disable:4231)  

// needs to have dll-interface used by client
# pragma warning(disable:4251)  

// non dll-interface struct
# pragma warning(disable:4275)  

// 'int' : forcing value to bool 'true' or 'false' (performance warning)
# pragma warning(disable:4800)  
#endif


// include first to avoid _POSIX_C_SOURCE warning.
#include <boost/python.hpp>


using namespace boost::python;

#include "PyNTuple.h"

namespace hippodraw {
namespace Python {


void
export_PyNTuple()
{
  class_ < PyNTuple, bases < NTuple > >
    ( "NTuple",
      "A derived class of DataSource that stores its tabular data vectors of\n"
      "double precision numbers in C++.  An NTuple object can be created in\n"
      "a number of ways including reading from a file using the\n"
      "NTupleController",
      init<>
      ( "NTuple ( None ) -> NTuple\n"
	"NTuple ( value ) -> NTuple\n"
	"NTuple ( sequence ) -> NTuple\n"
	"NTuple ( NTuple ) -> NTuple\n"
	"\n"
	"The form with no arguments creates an empty NTuple with no rows\n"
	"or columns.   The form with one value argument creates an empty\n"
	"NTuple with `value' number of columns.   The form with a sequence\n"
	"argument creates an empty NTuple with the number of columns equal\n"
	"to size of the sequence.   The sequence should contain string which\n"
	"are used as the column labels.   The last form form creates an\n"
	"NTuple\n whose contents is a copy of an existing one." ) )

    .def ( init < unsigned int > ( ) )

    .def ( init < const std::vector < std::string  > & > ( ) )

    .def ( init < const PyNTuple & > () )

    .def ( "setTitle", &PyNTuple::setTitle,
	   "setTitle ( string ) -> None\n"
	   "\n"
	   "Sets the title of the ntuple.  The title by default appears at\n"
	   "the top of a Display." )
	   
//     .def ( "addColumn", 
// 	   ( int ( PyNTuple::* ) // function pointer cast
// 	     ( const std::string &,
// 	       const std::vector < float > & ) )
// 	   &PyNTuple::addColumn,
// 	   "addColumn ( label, sequence<float> ) -> index\n"
// 	   "\n"
// 	   "Adds a new column with label." )

    .def ( "addColumn", 
	   ( int ( PyNTuple::* ) // function pointer cast
	     ( const std::string &,
	       const std::vector < double > & ) )
	   &PyNTuple::addColumn,
	   "addColumn ( label, sequence<double> ) -> index\n"
	   "\n"
	   "Adds a new column with label." )

    .def ( "append", &PyNTuple::append,
	   "append ( DataSource ) -> None\n"
	   "\n"
	   "Appends the contents of the DataSource to the NTuple." )

    .def ( "replaceColumn",
	   ( void ( PyNTuple::* ) // function pointer cast
	     ( unsigned int,
	       const std::vector < double > & ) )
	   &PyNTuple::replaceColumn,
	   "replaceColumn ( index, sequence ) -> None\n"
	   "\n"
	   "Replaces the indexed column." )

    .def ( "replaceColumn",
	   ( void ( PyNTuple::* ) // function pointer cast
	     ( const std::string &, const std::vector < double > & ) )
	   &PyNTuple::replaceColumn,
	   "replaceColumn ( label, sequence ) -> None\n"
	   "\n"
	   "Replaces the labeled  column." )

    .def ( "addRow",
	   &PyNTuple::addRow,
	   "addRow ( sequence ) -> None\n"
	   "\n"
	   "Append a row at the end." )

    .def ( "clear",
	   &PyNTuple::clear,
	   "clear () -> None\n"
	   "\n"
	   "Clears the data elements of the DataSource.   That is, remove\n"
	   "all the rows while keeping the column labels." )

    ;
}
} // namespace Python
} // namespace hippodraw
